==> qore-1.12.4.tar.bz2: qore-1.12.4/docs/library/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language - C/C++ Library", "index.html", [
    [ "Programming with the Qore Library", "index.html", null ],
    [ "Embedding Qore Code", "embedding_page.html", [
      [ "Embedding Qore Code", "embedding_page.html#embedding", [
        [ "Initializing and Closing the Qore Library", "embedding_page.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding_page.html#parsing_and_running", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions_page.html", [
      [ "Qore Builtin Functions", "builtin_functions_page.html#builtin_functions", [
        [ "Handling Function Arguments", "builtin_functions_page.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions_page.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions_page.html#function_raising_exceptions", null ]
      ] ]
    ] ],
    [ "Implementing Qore Classes", "class_implementation_page.html", [
      [ "Implementing Qore Classes", "class_implementation_page.html#class_implementation", [
        [ "Constructor Methods", "class_implementation_page.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation_page.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation_page.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation_page.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation_page.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation_page.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation_page.html#class_hierarchies", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html", [
      [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html#dbi_drivers", [
        [ "DBI Function Overview", "dbi_drivers_page.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers_page.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers_page.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers_page.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers_page.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers_page.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers_page.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers_page.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers_page.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers_page.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers_page.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers_page.html#dbi_get_client_version", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_abstract_exception_8h.html",
"_qore_lib_8h.html#a66931c5e8a92b2119cdf36a9681c468e",
"_system_environment_8h_source.html",
"class_datasource.html#a95c220bb8913288aefc8394640e26b9d",
"class_module_manager.html#a6b751871b3782d736eb54543c58b0128",
"class_qore_condition.html#aacbdb4cceaca5e16901b6afbe921bf1a",
"class_qore_ftp_client.html#ab5b06d39719cebdfcfb66e3df65bfb3f",
"class_qore_namespace.html#ae2ef632e98e9956775ae5bab3fc5aebc",
"class_qore_program.html#a2763462ef87578faf348aea62946711b",
"class_qore_socket.html#a388cdc002298b4a4adab8532216abc80",
"class_qore_string.html#aad6c797e340e3c6dcef8b2c9ddccd1c9",
"class_root_qore_namespace.html#a1285fcb9860e3cf4bfc4568f6db8300a",
"functions_func_c.html",
"params_8h_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.13.0.tar.bz2: qore-1.13.0/docs/library/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language - C/C++ Library", "index.html", [
    [ "Programming with the Qore Library", "index.html", null ],
    [ "Embedding Qore Code", "embedding_page.html", [
      [ "Embedding Qore Code", "embedding_page.html#embedding", [
        [ "Initializing and Closing the Qore Library", "embedding_page.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding_page.html#parsing_and_running", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions_page.html", [
      [ "Qore Builtin Functions", "builtin_functions_page.html#builtin_functions", [
        [ "Handling Function Arguments", "builtin_functions_page.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions_page.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions_page.html#function_raising_exceptions", null ]
      ] ]
    ] ],
    [ "Implementing Qore Classes", "class_implementation_page.html", [
      [ "Implementing Qore Classes", "class_implementation_page.html#class_implementation", [
        [ "Constructor Methods", "class_implementation_page.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation_page.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation_page.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation_page.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation_page.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation_page.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation_page.html#class_hierarchies", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html", [
      [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html#dbi_drivers", [
        [ "DBI Function Overview", "dbi_drivers_page.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers_page.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers_page.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers_page.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers_page.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers_page.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers_page.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers_page.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers_page.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers_page.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers_page.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers_page.html#dbi_get_client_version", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_abstract_exception_8h.html",
"_qore_lib_8h.html#a66931c5e8a92b2119cdf36a9681c468e",
"_scope_guard_8h_source.html",
"class_datasource.html#a919f6233fb05acef204a9f8bf38ed7b5",
"class_module_manager.html",
"class_qore_condition.html#a6a97ce40a1704004ae0666f7eb8e09fc",
"class_qore_ftp_client.html#aab7772a74fda3706551ccecc9d9db883",
"class_qore_namespace.html#ad7925a6edf04c67d8a24d0e3b4af12fc",
"class_qore_program.html#a234e8af90adf814c03842c291aa18adf",
"class_qore_socket.html#a3239383995643a1eff7f36a399a4d763",
"class_qore_string.html#aa82d6f9e9ae65bdca67bf34c06942872",
"class_reverse_hash_iterator.html#ac6a42c4614b6f621ba4924e90696ab46",
"functions_func_a.html",
"params_8h.html#acfe2ba0a5180643def44cf686f9a976d"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
